/*
  This file is a part of unixcw project.
  unixcw project is covered by GNU General Public License.
*/

#ifndef H_LIBCW_OSS
#define H_LIBCW_OSS





#include "libcw_gen.h"

int cw_oss_configure(cw_gen_t *gen, const char *device);





#endif /* #ifndef H_LIBCW_OSS */
